@@ -2,15 +2,20 @@
 # original code from the deal package, released under "GPLv2 or later"
 # with copyright "2002  Susanne Gammelgaard Bottcher, Claus Dethlefsen".
 
-# write the model formula of an object of class 'bn'.
+# write the model formula of an object of class 'bn' or 'bn.fit'.
 # (ported from the deal package)
 formula.backend = function(x) {
 
+  if (class(x) == "bn")
+    base = x$nodes
+  else
+    base = x
+
   paste(sapply(schedule(x),
     function(node) {
 
-      paste("[", node, ifelse(length(x$nodes[[node]]$parents) > 0, "|", ""),
-        paste(x$nodes[[node]]$parents, sep="", collapse=":"), "]", sep = "")
+      paste("[", node, ifelse(length(base[[node]]$parents) > 0, "|", ""),
+        paste(base[[node]]$parents, sep="", collapse=":"), "]", sep = "")
 
     } ), collapse = "")
 
