@@ -109,8 +109,8 @@ tabu.search = function(x, start, whitelist, blacklist, score,
 
     # select which arcs should be tested for inclusion in the graph (hybrid
     # learning algorithms should hook the restrict phase here).
-    to.be.added = arcs.to.be.added(amat = amat, nodes = nodes, blmat = blmat,
-                    arcs = FALSE)
+    to.be.added = arcs.to.be.added(amat = amat, nodes = nodes, 
+                    blacklist = blmat, whitelist = NULL, arcs = FALSE)
 
     # get the best arc addition/removal/reversal.
     bestop = .Call("tabu_step",
